#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# SPDX-License-Identifier: Apache-2.0
# Copyright 2022 Stéphane Caron

"""Import open source robot description as Python modules."""

from ._descriptions import DESCRIPTIONS

__version__ = "1.21.0"

__all__ = ["DESCRIPTIONS"]
